@@ -12,6 +12,7 @@
 #include <stan/math/opencl/kernels/device_functions/lbeta.hpp>
 #include <stan/math/opencl/kernels/device_functions/lgamma_stirling.hpp>
 #include <stan/math/opencl/kernels/device_functions/lgamma_stirling_diff.hpp>
+#include <stan/math/opencl/kernels/device_functions/lmultiply.hpp>
 #include <stan/math/opencl/kernels/device_functions/log_inv_logit.hpp>
 #include <stan/math/opencl/kernels/device_functions/log_inv_logit_diff.hpp>
 #include <stan/math/opencl/kernels/device_functions/log_diff_exp.hpp>
@@ -318,7 +319,12 @@ ADD_UNARY_FUNCTION_WITH_INCLUDES(
     log1m_inv_logit, opencl_kernels::log1m_inv_logit_device_function)
 ADD_UNARY_FUNCTION_WITH_INCLUDES(trigamma,
                                  opencl_kernels::trigamma_device_function)
-ADD_UNARY_FUNCTION_WITH_INCLUDES(square, "double square(double x){return x*x;}")
+ADD_UNARY_FUNCTION_WITH_INCLUDES(
+    square,
+    "\n#ifndef STAN_MATH_OPENCL_KERNELS_DEVICE_FUNCTIONS_SQUARE\n"
+    "#define STAN_MATH_OPENCL_KERNELS_DEVICE_FUNCTIONS_SQUARE\n"
+    "double square(double x){return x*x;}\n"
+    "#endif\n")
 
 ADD_CLASSIFICATION_FUNCTION(isfinite, {-rows() + 1, cols() - 1})
 ADD_CLASSIFICATION_FUNCTION(isinf,
@@ -326,9 +332,14 @@ ADD_CLASSIFICATION_FUNCTION(isinf,
 ADD_CLASSIFICATION_FUNCTION(isnan,
                             this->template get_arg<0>().extreme_diagonals())
 
+ADD_BINARY_FUNCTION_WITH_INCLUDES(fdim)
+ADD_BINARY_FUNCTION_WITH_INCLUDES(fmax)
+ADD_BINARY_FUNCTION_WITH_INCLUDES(fmin)
+ADD_BINARY_FUNCTION_WITH_INCLUDES(fmod)
 ADD_BINARY_FUNCTION_WITH_INCLUDES(hypot)
 ADD_BINARY_FUNCTION_WITH_INCLUDES(ldexp)
 ADD_BINARY_FUNCTION_WITH_INCLUDES(pow)
+ADD_BINARY_FUNCTION_WITH_INCLUDES(copysign)
 
 ADD_BINARY_FUNCTION_WITH_INCLUDES(
     beta, stan::math::opencl_kernels::beta_device_function)
@@ -351,6 +362,8 @@ ADD_BINARY_FUNCTION_WITH_INCLUDES(log_diff_exp,
                                   opencl_kernels::log_diff_exp_device_function)
 ADD_BINARY_FUNCTION_WITH_INCLUDES(
     multiply_log, stan::math::opencl_kernels::multiply_log_device_function)
+ADD_BINARY_FUNCTION_WITH_INCLUDES(
+    lmultiply, stan::math::opencl_kernels::lmultiply_device_function)
 
 #undef ADD_BINARY_FUNCTION_WITH_INCLUDES
 #undef ADD_UNARY_FUNCTION_WITH_INCLUDES
