@@ -18,10 +18,10 @@ namespace math {
 template <typename T,
           require_all_kernel_expressions_and_none_scalar_t<T>* = nullptr>
 inline var_value<matrix_cl<double>> log1m(const var_value<T>& A) {
-  return make_callback_var(
-      log1m(A.val()), [A](vari_value<matrix_cl<double>>& res) mutable {
-        A.adj() = A.adj() + elt_divide(res.adj(), A.val() - 1.0);
-      });
+  return make_callback_var(log1m(A.val()),
+                           [A](vari_value<matrix_cl<double>>& res) mutable {
+                             A.adj() += elt_divide(res.adj(), A.val() - 1.0);
+                           });
 }
 
 }  // namespace math
